#!/usr/bin/env python
#
# This program generates the US Counties data model for ACS Reference
# based on the raw data file (counties.txt) obtained from:
#
# http://ftp.census.gov/geo/www/gazetteer/places.html
#
# Ron Henderson (ron@arsdigita.com), 2001-01-22
#
# $Id: counties.py,v 1.2 2001/01/24 02:17:03 ron Exp $
# -----------------------------------------------------------------------------

import sys, os, string

usage = 'counties.py [-o file] [-h] counties.txt'
help  = '''
-h      print this help message
-o file write output to a named file rather than stdout'''

# Represents one record in the US Counties Data File

class County:
    def __init__(self, info):

        self.fips_state    = string.strip(info[0:2])
        self.fips_county   = string.strip(info[3:8])
        self.name          = string.strip(info[9:75])
        self.state_abbrev  = string.strip(info[76:78])
        self.population    = string.strip(info[79:88])
        self.housing_units = string.strip(info[89:98])
        self.land_area     = string.strip(info[99:109])
        self.water_area    = string.strip(info[110:120])
        self.latitude      = string.strip(info[121:130])
        self.longitude     = string.strip(info[131:140])

        # Convert quotes to double quotes

        self.name = string.replace(self.name,"'","''")

    def __repr__(self):
        return "insert into us_counties values ('%s','%s','%s','%s',%s,%s,%s,%s,%s,%s);" % \
               (self.fips_state, self.fips_county, self.name, self.state_abbrev, \
                self.population, self.housing_units, self.land_area, self.water_area, \
                self.latitude, self.longitude)

# -----------------------------------------------------------------------------

def parse_args(argv):
    for i in range(1,len(argv)):
        arg = argv[i]
        if arg == '-h':
            print usage + help
            sys.exit()
        elif arg == '-o':
            print "not implemented"
        else:
            print "unknown option -- " + arg

    return

# -----------------------------------------------------------------------------

counties  = 'counties.txt'
out       = sys.stdout
verbose   = 0

parse_args(sys.argv)

print '''-- packages/acs-reference/sql/us-counties.sql
--
-- This file is generated automatically based on the US counties
-- database provided by the US Census Bureau.
--
-- $Id: counties.py,v 1.2 2001/01/24 02:17:03 ron Exp $

set feedback off;
'''

count = 0

for line in open(counties,'r').readlines():
    print County(line)
    count = count + 1


print '''
set feedback on;

-- End of US Counties Database (%d records)''' % count



