#!/usr/bin/env python
#
# This program generates the US Zipcodes data model for ACS Reference
# based on the raw data file (zipnov99.dbf) obtained from the US Census Bureau.
#
# Ron Henderson (ron@arsdigita.com), 2001-01-22
#
# $Id: zipdbf.py,v 1.1.2.2 2001/01/26 17:35:03 ron Exp $
# -----------------------------------------------------------------------------

import sys, os, string, struct

# class for storing database field information

class DBField:
    def __init__(self, info):
        self.name     = string.strip(info[0:10])
        self.type     = string.strip(info[11:12])
        self.position = struct.unpack('B',info[12:13])[0]
        self.length   = struct.unpack('B',info[16:17])[0]
        return

    def extract (self, line):
        i = self.position
        j = self.position + self.length
        return string.strip(line[i:j])

    def __repr__(self):
        print self.name
        print self.type
        print self.position
        print self.length
        return
    
# class for storing / printing basic zipcode records

class ZipCode:
    def __init__(self,fields,line):
    
        # parse the line into records
        record = []
        for n in range(len(fields)):
                record.append(fields[n].extract(line))

        # store records into the correct attributes
        self.zipcode     = record[0]
        self.latitude    = record[1]
        self.longitude   = record[2]
        self.zipclass    = record[3]
        self.name        = record[4]
        self.fips_state  = record[5]
        self.fips_county = record[6]

        # might need quote protection for oracle
        self.name = string.replace(self.name,"'","''")

    def sql(self):
        return "insert into us_zipcodes values ('%s','%s','%s','%s',%s,%s);" % \
               (self.zipcode, self.name, self.fips_state, self.fips_county, \
                self.latitude, self.longitude)
        
# -----------------------------------------------------------------------------

# By default we read from the 1999 zipcodes database file
    
dbf = open('zipnov99.dbf','r')
sql = open('us-zipcodes-data.sql','w');

# debugging - ship to stdout
# sql = sys.stdout

# Ignore the magic 32 bit header, even though this probably tells you
# how many lines the full header information occupies.

dbf.read(32)

# Now scan to the first line that contains a non-alphanumeric
# character at the beginning.  Create a list of field headers along
# the way.

field = []
line  = dbf.read(32);
while line[0].isalpha():
    field.append(DBField(line))
    line = dbf.read(32);

# Compute the total record length by adding up the length of each field

record_length = 0
for i in range(len(field)):
    record_length = record_length + field[i].length

# database file header

sql.write('''-- packages/acs-reference/sql/us-zipcodes-data.sql
--
-- This file is generated automatically based on the US zipcodes
-- database provided by the US Census Bureau.
--
-- $Id: zipdbf.py,v 1.1.2.2 2001/01/26 17:35:03 ron Exp $

set feedback off;

''')

# Combine the last read with the rest of the first record and then
# covert the remaining lines in the file

count = 0
line  = line[1:] + dbf.read(record_length + 2 - len(line))

while len(line) > 1:
    sql.write(ZipCode(field,line).sql() + '\n')
    line  = dbf.read(record_length+1)
    count = count + 1

# database file footer

sql.write('''
set feedback on;

-- End of US Zipcode Database (%d records)
''' % count)
